@@ -5,11 +5,13 @@ use cust_raw::{CUstream, CUstream_st};
 
 use super::ToCudaResult;
 
+/// Represents an owned CUDA Stream.
 pub struct Stream {
     inner: NonNull<CUstream_st>,
 }
 
 impl Stream {
+    /// Create a new CUDA Stream
     pub fn new() -> CudaResult<Self> {
         let mut stream = std::ptr::null_mut();
 
@@ -39,18 +41,12 @@ impl Drop for Stream {
     }
 }
 
+/// A Shared CUDA Stream. Created through [`Deref`] from [`Stream`].
+/// Is a DeviceAllocator for Cuda
 pub struct SharedStream(CUstream_st);
 
 impl SharedStream {
-    pub(crate) fn inner(&self) -> CUstream {
+    pub fn inner(&self) -> CUstream {
         self as *const _ as *mut _
     }
-
-    #[cfg(feature = "cublas")]
-    pub fn init_cublas<'a>(
-        &'a self,
-        ctx: &'a crate::blas::cublas::CublasContext,
-    ) -> &'a crate::blas::cublas::SharedCublasContext {
-        ctx.with_stream(Some(self))
-    }
 }
